<template>
  <div>
    <el-bus-crud ref="crud" v-bind="tableConfig" />
    <el-dialog title="积分变动记录" :visible.sync="dialogVisible" width="80%">
      <el-bus-crud
        v-if="customerId"
        :key="dialogId"
        :extra-query="{ customerId }"
        v-bind="recordTableConfig"
      />
    </el-dialog>
  </div>
</template>

<script>
import { v4 as uuidv4 } from 'uuid'
export default {
  data() {
    return {
      dialogVisible: false,
      customerId: null,
      dialogId: null,
      tableConfig: {
        url: 'flower/api/customer/point/page',
        hasNew: false,
        hasEdit: false,
        hasDelete: false,
        hasView: false,
        columns: [
          { label: '序号', type: 'index' },
          { label: '用户信息', prop: 'customerName' },
          { label: '联系方式', prop: 'customerTel' },
          { label: '总积分', prop: 'totalPoint' },
          { label: '已使用积分', prop: 'usedPoint' },
          { label: '过期积分', prop: 'expiredPoint' },
          { label: '扣减积分', formatter: (row) => row.deductionPoint ?? 0 },
          {
            label: '剩余积分',
            formatter: (row) =>
              parseInt(row.totalPoint) -
              parseInt(row.deductionPoint ?? 0) -
              parseInt(row.usedPoint) -
              parseInt(row.expiredPoint),
          },
        ],
        searchForm: [
          {
            type: 'row',
            items: [{ label: '用户名称', id: 'customerName', type: 'input' }],
          },
        ],
        extraDialogs: [
          {
            title: '积分赠送',
            form: [
              {
                id: 'customerId',
                type: 'input',
                hidden: () => true,
              },
              {
                label: '积分赠送：',
                id: 'point',
                type: 'input-number',
                el: {
                  precision: 0,
                  min: 1,
                  max: 99999999,
                  controls: false,
                },
                rules: {
                  required: true,
                  message: '请输入积分赠送',
                  trigger: 'blur',
                },
              },
              {
                label: '原因：',
                id: 'remarks',
                type: 'input',
                el: {
                  type: 'textarea',
                  rows: 6,
                },
                rules: {
                  required: true,
                  message: '请输入原因',
                  trigger: 'blur',
                },
              },
            ],
            atConfirm: async (val) => {
              const { code } = await this.$elBusHttp.request(
                'flower/api/customer/point/giveaway',
                {
                  method: 'post',
                  data: val,
                }
              )
              if (code === 0) {
                this.$message.success('赠送成功')
              }
            },
          },
          {
            title: '积分扣减',
            form: [
              {
                id: 'customerId',
                type: 'input',
                hidden: () => true,
              },
              {
                label: '积分扣减：',
                id: 'point',
                type: 'input-number',
                el: {
                  precision: 0,
                  min: 1,
                  max: 99999999,
                  controls: false,
                },
                rules: {
                  required: true,
                  message: '请输入积分扣减',
                  trigger: 'blur',
                },
              },
              {
                label: '原因：',
                id: 'remarks',
                type: 'input',
                el: {
                  type: 'textarea',
                  rows: 6,
                },
                rules: {
                  required: true,
                  message: '请输入原因',
                  trigger: 'blur',
                },
              },
            ],
            atConfirm: async (val) => {
              const { code } = await this.$elBusHttp.request(
                'flower/api/customer/point/deduction',
                {
                  method: 'post',
                  data: val,
                }
              )
              if (code === 0) {
                this.$message.success('扣减成功')
              }
            },
          },
        ],
        extraButtons: [
          {
            text: '积分变动记录',
            atClick: (row) => {
              this.dialogId = uuidv4()
              this.customerId = row.customerId
              this.dialogVisible = true
            },
          },
          {
            text: '积分赠送',
            atClick: (row) => {
              this.$refs.crud.$refs.extraDialog[0].show(row)
              return false
            },
          },
          {
            text: '积分扣减',
            atClick: (row) => {
              this.$refs.crud.$refs.extraDialog[1].show(row)
              return false
            },
          },
        ],
      },
      recordTableConfig: {
        url: 'flower/api/customer/point/page/list',
        saveQuery: false,
        hasNew: false,
        hasOperation: false,
        columns: [
          { label: '序号', type: 'index' },
          { label: '变动类型', prop: 'changeTypeStr' },
          { label: '变动积分', prop: 'point' },
          { label: '变动原因', prop: 'typeStr' },
          { label: '变动时间', prop: 'recordDate' },
          { label: '备注', prop: 'remarks' },
        ],
        searchFormAttrs: {
          labelWidth: 'auto',
        },
        searchForm: [
          {
            type: 'row',
            items: [
              {
                label: '变动原因：',
                id: 'type',
                type: 'bus-radio',
                el: {
                  code: 'point_type',
                  childType: 'el-radio-button',
                  hasAll: true,
                },
                default: '',
                searchImmediately: true,
                span: 24,
              },
              {
                label: '备注：',
                id: 'remarks',
                type: 'input',
              },
            ],
          },
        ],
      },
    }
  },
  head() {
    return {
      title: '积分发放',
    }
  },
}
</script>
